slepc-3.18.0 2022-10-01
Report Typos and Errors

# RGSetComplement

Sets a flag to indicate that the region is the complement of the specified one.

### Synopsis

    #include "slepcrg.h"
    PetscErrorCode RGSetComplement(RG rg,PetscBool flg)

Logically Collective on rg

### Input Parameters

| rg | - the region context
| flg | - the boolean flag

### Options Database Key

| -rg_complement <bool> | - Activate/deactivate the complementation of the region

### See Also

RGGetComplement()

### Level

intermediate

### Location

src/sys/classes/rg/rgbasic.c

### Examples

src/eps/tutorials/ex30.c.html
Index of all RG routines
Table of Contents for all manual pages
Index of all manual pages